@@ -6,7 +6,11 @@ from typing import Dict, List
 from secfsdstools.d_index.indexdataaccess import IndexReport
 from secfsdstools.e_read.companyreading import CompanyReader
 
-if __name__ == '__main__':
+def run():
+    # pylint: disable=W0612
+    """
+    run the example
+    """
     apple_cik: int = 320193
 
     # getting the company reader instance for apple
@@ -28,3 +32,7 @@ if __name__ == '__main__':
     # for instance, if you are only interested in annual and quarter reports, you can use
     apple_10k_and_10q_reports_df = apple_reader.get_all_company_reports_df(forms=['10-K', '10-Q'])
     print(apple_10k_and_10q_reports_df)
+
+
+if __name__ == '__main__':
+    run()
